## CSS - Demos - Layout 1

<script type="module" src="/web_components/js/css/layouts/WebC__CSS__Layout_2.mjs"></script>

<webc-container>
    <webc-css-layout-2        ></webc-css-layout-2> 
    <webc-css-layout-2 no-css ></webc-css-layout-2>
</webc-container>

<webc-container>
    <webc-css-layout-2></webc-css-layout-2>
    <webc-css-layout-2></webc-css-layout-2>
    <webc-css-layout-2></webc-css-layout-2>
</webc-container>
    